aio-standalone
==============

|Build Status|

Standalone application server framework using asyncio.

Installation
------------

Grab it off pypi:

::

    pip install aio-standalone

Or grab it off github:

::

    git clone https://github.com/kblin/aio-standalone.git
    cd aio-standalone
    pip install .

License
-------

| All code is available under the Apache License version 2, see the
| ```LICENSE`` <LICENSE>`__ file for details.

.. |Build Status| image:: https://github.drone.secondarymetabolites.org/api/badges/kblin/aio-standalone/status.svg
   :target: https://github.drone.secondarymetabolites.org/kblin/aio-standalone
